r23714 - gnucash/trunk/src/report/standard-reports - Advanced Portfolio: Use the more common LIFO name for the basis method.

Mike Alexander mta at code.gnucash.org
Sun Jan 19 02:09:44 EST 2014


Author: mta
Date: 2014-01-19 02:09:44 -0500 (Sun, 19 Jan 2014)
New Revision: 23714
Trac: http://svn.gnucash.org/trac/changeset/23714

Modified:
   gnucash/trunk/src/report/standard-reports/advanced-portfolio.scm
Log:
Advanced Portfolio: Use the more common LIFO name for the basis method.

Don't change the internal code to avoid invalidating saved reports.

Modified: gnucash/trunk/src/report/standard-reports/advanced-portfolio.scm
===================================================================
--- gnucash/trunk/src/report/standard-reports/advanced-portfolio.scm	2014-01-19 07:09:21 UTC (rev 23713)
+++ gnucash/trunk/src/report/standard-reports/advanced-portfolio.scm	2014-01-19 07:09:44 UTC (rev 23714)
@@ -95,8 +95,8 @@
 		    (N_ "FIFO")
 		    (N_ "Use first-in first-out method for basis."))
 	    (vector 'filo-basis
-		    (N_ "FILO")
-		    (N_ "Use first-in last-out method for basis."))
+		    (N_ "LIFO")
+		    (N_ "Use last-in first-out method for basis."))
 	    )))
 
     (add-option
@@ -226,7 +226,7 @@
 	)    
     )
   
   ;; this builds a list for basis calculation and handles average, fifo and filo methods
   ;; the list is cons cells of (units-of-stock . price-per-unit)... average method produces only one
   ;; cell that mutates to the new average. Need to add a date checker so that we allow for prices
   ;; coming in out of order, such as a transfer with a price adjusted to carryover the basis.
@@ -226,7 +226,7 @@
     )
   
-  ;; this builds a list for basis calculation and handles average, fifo and filo methods
+  ;; this builds a list for basis calculation and handles average, fifo and lifo methods
   ;; the list is cons cells of (units-of-stock . price-per-unit)... average method produces only one
   ;; cell that mutates to the new average. Need to add a date checker so that we allow for prices



More information about the gnucash-changes mailing list